@@ -1,6 +1,6 @@
-(*----------------------------------------------------------------------------
-   Copyright (c) 2009-2010, Daniel C. Bünzli. All rights reserved.
-   Distributed under a BSD license, see license at the end of the file.
+(*---------------------------------------------------------------------------
+   Copyright (c) (c) 2009-2012 Daniel C. Bünzli. All rights reserved.
+   Distributed under a BSD3 license, see license at the end of the file.
   ---------------------------------------------------------------------------*)
 
 (* Breakout clone. *)
@@ -447,7 +447,7 @@ let main () =
 let ui = main ()                               (* keep a ref. to avoid g.c. *)
 
 (*----------------------------------------------------------------------------
-  Copyright (c) 2009-2010, Daniel C. Bünzli
+  Copyright (c) 2009-2012 Daniel C. Bünzli
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -462,7 +462,7 @@ let ui = main ()                               (* keep a ref. to avoid g.c. *)
      documentation and/or other materials provided with the
      distribution.
 
-  3. Neither the name of the Daniel C. Bünzli nor the names of
+  3. Neither the name of Daniel C. Bünzli nor the names of
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.
 
